using System;
using System.IO;
using System.IO.Packaging;
using System.Xml;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace CreateNewXLFile
{
  public partial class Form1 : Form
  {

    private const string mainContentType = 
       @"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml";

    private const string sheetContentType = 
       @"application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml";

    private const string mainRelationshipSchema = 
       @"http://schemas.openxmlformats.org/officeDocument/2006/relationships";

    private string pathDesktop = System.Environment.GetFolderPath(Environment.SpecialFolder.Desktop);


    #region "Form Events"
    
    public Form1()
    {
      InitializeComponent();
    }

    private void Form1_Load(object sender, EventArgs e)
    {
      cboCell1.SelectedIndex = 0;
      cboCell2.SelectedIndex = 0;
    }

    private void button1_Click(object sender, EventArgs e)
    {
      string FName = "TestWorkbook.xlsx";
      dlgFileSave.FileName = FName;
      if (dlgFileSave.ShowDialog() == DialogResult.OK)
      {
        if (!FName.EndsWith(".xlsx"))
          FName += ".xlsx";
        SaveXLSX(FName);
      }
    }

    #endregion


    private void SaveXLSX(string zipFileName)
    {
      // Read Workbook.xml:
      XmlDocument xDocWB = new XmlDocument();
      xDocWB.Load(pathDesktop + @"\Workbook.xml");

      // Read the worksheet:
      XmlDocument xDocWS = new XmlDocument();
      xDocWS.Load(pathDesktop + @"\Worksheet.xml");
    
      using (Package zipPack = Package.Open(zipFileName, FileMode.Create, FileAccess.ReadWrite))
      {
        // save a temporary part to create the default application/xml content type
        // <Default Extension="xml" ContentType="application/xml"/>
        Uri uriDefaultContentType = new Uri("/default.xml", UriKind.Relative);
        PackagePart partTemp = zipPack.CreatePart(uriDefaultContentType, "application/xml");

        // save the main document part (workbook.xml)
        Uri uriWB = new Uri("/xl/workbook.xml", UriKind.Relative);
        PackagePart partWB = zipPack.CreatePart(uriWB, mainContentType);
        using (StreamWriter sw = new StreamWriter(partWB.GetStream(FileMode.Create, FileAccess.ReadWrite)))
        {
          xDocWB.Save(sw);
        }

        // create the main relationship part
        zipPack.CreateRelationship(uriWB, TargetMode.Internal, mainRelationshipSchema +
          @"/officeDocument", "rId1");

        // save the worksheet (sheet1.xml)
        Uri uriWs = new Uri("/xl/worksheets/sheet1.xml", UriKind.Relative);
        PackagePart partWS = zipPack.CreatePart(uriWs, sheetContentType);
        using (StreamWriter sw = new StreamWriter(partWS.GetStream(FileMode.Create, FileAccess.ReadWrite)))
        {
          xDocWS.Save(sw);
        }

        // create the workbook relationship part
        partWB.CreateRelationship(uriWs, TargetMode.Internal, mainRelationshipSchema +
          @"/worksheet", "rId1");

        // Delete the temporary part
        zipPack.DeletePart(uriDefaultContentType);

        zipPack.Flush();
      }
    }

  }
}